pub struct TakServerSetting<'a> {
pub tls: bool,
pub client_credentials: Option<Credentials<'a>>,
pub ignore_invalid: bool,
pub verify_hostname: bool,
pub auto_reconnect: bool,
pub reconnect_delay: u64,
}Expand description
Tak server connection settings
Fields
tls: boolUse TLS for the connection
client_credentials: Option<Credentials<'a>>Optional client credentials for mutual TLS authentication
ignore_invalid: boolIgnore invalid server certificates (self-signed, expired, hostname mismatch) - WARNING this disables some protections, but may be necessary for some TAK server configurations
verify_hostname: boolVerify the server hostname against the certificate (Common Name / SAN) - WARNING this disables some protections, but may be necessary for some TAK server configurations
auto_reconnect: boolAutomatically reconnect on connection loss
reconnect_delay: u64Auto reconnect delay in seconds